@@ -1,9 +1,10 @@
 // SPDX-License-Identifier: MIT OR LGPL-2.0-or-later
 // SPDX-FileCopyrightText: 2021 Andy Holmes <andyholmes@gnome.org>
 
-imports.gi.versions.Gtk = '4.0';
-const {GLib, GObject, Gio, Gtk} = imports.gi;
-
+import GLib from 'gi://GLib';
+import GObject from 'gi://GObject';
+import Gio from 'gi://Gio';
+import Gtk from 'gi://Gtk?version=4.0';
 
 Gtk.init();
 
@@ -15,8 +16,9 @@ Gtk.init();
  *   - an absolute file URI, such as `file:///home/user/window.ui`
  *   - a GResource URI, such as `resource:///org/gnome/AppName/window.ui`
  */
-const file = Gio.File.new_for_path('gtk4-template.ui');
-const [, template] = file.load_contents(null);
+const file = Gio.File.new_for_uri(import.meta.url);
+const templateFile = file.get_parent().resolve_relative_path('gtk4-template.ui');
+const [, template] = templateFile.load_contents(null);
 
 
 const ExampleWindow = GObject.registerClass({
