@@ -568,44 +568,3 @@ JSObject* gjs_new_object_with_generic_prototype(JSContext* cx,
 
     return JS_NewObjectWithGivenProto(cx, JS::GetClass(proto), proto);
 }
-
-// Handle the case where g_irepository_find_by_gtype() returns a type in Gio
-// that should be in GioUnix or GioWin32. This may be an interface, class, or
-// boxed. This function only needs to be called if you are going to do something
-// with the GIBaseInfo that involves handing a JS object to the user. Otherwise,
-// use g_irepository_find_by_gtype() directly.
-Maybe<GI::AutoRegisteredTypeInfo> gjs_lookup_gtype(const GI::Repository& repo,
-                                                   GType gtype) {
-    Maybe<GI::AutoRegisteredTypeInfo> retval{repo.find_by_gtype(gtype)};
-    if (!retval)
-        return {};
-
-#if GLIB_CHECK_VERSION(2, 85, 5)
-    return retval;
-#endif  // GLib >= 2.85.5
-
-#if (defined(G_OS_UNIX) || defined(G_OS_WIN32))
-#    ifdef G_OS_UNIX
-    static const char* c_prefix = "GUnix";
-    static const char* new_ns = "GioUnix";
-#    else  // G_OS_WIN32
-    static const char* c_prefix = "GWin32";
-    static const char* new_ns = "GioWin32";
-#    endif
-
-    if (strcmp(retval->ns(), "Gio") != 0)
-        return retval;
-
-    const char* gtype_name = g_type_name(gtype);
-    if (!g_str_has_prefix(gtype_name, c_prefix))
-        return retval;
-
-    const char* new_name = gtype_name + strlen(c_prefix);
-    Maybe<GI::AutoRegisteredTypeInfo> new_info =
-        repo.find_by_name<GI::InfoTag::REGISTERED_TYPE>(new_ns, new_name);
-    if (new_info)
-        return new_info;
-#endif  // (defined(G_OS_UNIX) || defined(G_OS_WIN32))
-
-    return retval;
-}
