@@ -8,7 +8,9 @@
 
 #include <stdint.h>
 
-#include <utility>      // IWYU pragma: keep (for swap)
+#include <algorithm>
+#include <type_traits>
+#include <utility>
 #include <vector>
 
 template <typename T>
