@@ -10,11 +10,10 @@
 
 #include <stdint.h>
 
-#include <new>
 #include <string>
 #include <type_traits>
 
-#include <girepository.h>
+#include <girepository/girepository.h>
 #include <glib-object.h>
 #include <glib.h>
 
