@@ -121,7 +121,7 @@ from_gbytes_func(JSContext *context,
                              "bytes", &bytes_obj))
         return false;
 
-    if (!BoxedBase::typecheck(context, bytes_obj, nullptr, G_TYPE_BYTES))
+    if (!BoxedBase::typecheck(context, bytes_obj, G_TYPE_BYTES))
         return false;
 
     gbytes = BoxedBase::to_c_ptr<GBytes>(context, bytes_obj);
