@@ -20,7 +20,8 @@ bool gjs_define_byte_array_stuff(JSContext              *context,
                                  JS::MutableHandleObject module);
 
 GJS_JSAPI_RETURN_CONVENTION
-JSObject* gjs_byte_array_from_data(JSContext* cx, size_t nbytes, void* data);
+JSObject* gjs_byte_array_from_data_copy(JSContext* cx, size_t nbytes,
+                                        void* data);
 
 GJS_JSAPI_RETURN_CONVENTION
 JSObject *    gjs_byte_array_from_byte_array (JSContext  *context,
