@@ -64,7 +64,6 @@ static GOptionEntry entries[] = {
 // clang-format on
 
 [[nodiscard]] static Gjs::AutoStrv strndupv(int n, char* const* strv) {
-#if GLIB_CHECK_VERSION(2, 68, 0)
     Gjs::AutoPointer<GStrvBuilder, GStrvBuilder, g_strv_builder_unref> builder{
         g_strv_builder_new()};
 
@@ -72,18 +71,6 @@ static GOptionEntry entries[] = {
         g_strv_builder_add(builder, strv[i]);
 
     return g_strv_builder_end(builder);
-
-#else
-
-    int ix;
-    if (n == 0)
-        return NULL;
-    char **retval = g_new(char *, n + 1);
-    for (ix = 0; ix < n; ix++)
-        retval[ix] = g_strdup(strv[ix]);
-    retval[n] = NULL;
-    return retval;
-#endif  // GLIB_CHECK_VERSION(2, 68, 0)
 }
 
 [[nodiscard]] static Gjs::AutoStrv strcatv(char** strv1, char** strv2) {
@@ -94,7 +81,6 @@ static GOptionEntry entries[] = {
     if (strv2 == NULL)
         return g_strdupv(strv1);
 
-#if GLIB_CHECK_VERSION(2, 70, 0)
     Gjs::AutoPointer<GStrvBuilder, GStrvBuilder, g_strv_builder_unref> builder{
         g_strv_builder_new()};
 
@@ -102,22 +88,6 @@ static GOptionEntry entries[] = {
     g_strv_builder_addv(builder, const_cast<const char**>(strv2));
 
     return g_strv_builder_end(builder);
-
-#else
-
-    unsigned len1 = g_strv_length(strv1);
-    unsigned len2 = g_strv_length(strv2);
-    char **retval = g_new(char *, len1 + len2 + 1);
-    unsigned ix;
-
-    for (ix = 0; ix < len1; ix++)
-        retval[ix] = g_strdup(strv1[ix]);
-    for (ix = 0; ix < len2; ix++)
-        retval[len1 + ix] = g_strdup(strv2[ix]);
-    retval[len1 + len2] = NULL;
-
-    return retval;
-#endif  // GLIB_CHECK_VERSION(2, 70, 0)
 }
 
 static gboolean parse_profile_arg(const char* option_name [[maybe_unused]],
