@@ -19,6 +19,7 @@
 #include <vector>
 
 #include <gio/gio.h>  // for GMemoryMonitor
+#include <girepository/girepository.h>
 #include <glib-object.h>
 #include <glib.h>
 
@@ -263,7 +264,7 @@ class GjsContextPrivate : public JS::JobQueue {
 
     // Implementations of JS::JobQueue virtual functions
     GJS_JSAPI_RETURN_CONVENTION
-    JSObject* getIncumbentGlobal(JSContext* cx) override;
+    bool getHostDefinedData(JSContext*, JS::MutableHandleObject) const override;
     GJS_JSAPI_RETURN_CONVENTION
     bool enqueuePromiseJob(JSContext* cx, JS::HandleObject promise,
                            JS::HandleObject job,
