@@ -23,7 +23,6 @@
 #    include <readline/history.h>
 #endif
 
-#include <new>
 #include <string>       // for u16string
 #include <thread>       // for get_id
 #include <unordered_map>
@@ -32,7 +31,7 @@
 #include <vector>
 
 #include <gio/gio.h>
-#include <girepository.h>
+#include <girepository/girepository.h>
 #include <glib-object.h>
 #include <glib.h>
 
@@ -43,6 +42,7 @@
 #include <js/CompilationAndEvaluation.h>
 #include <js/CompileOptions.h>
 #include <js/Context.h>
+#include <js/EnvironmentChain.h>
 #include <js/ErrorReport.h>
 #include <js/Exception.h>     // for StealPendingExceptionStack
 #include <js/GCAPI.h>         // for JS_GC, JS_AddExtraGCRootsTr...
@@ -359,7 +359,8 @@ gjs_context_class_init(GjsContextClass *klass)
         Gjs::AutoChar priv_typelib_dir{
             g_build_filename(PKGLIBDIR, "girepository-1.0", nullptr)};
 #endif
-        g_irepository_prepend_search_path(priv_typelib_dir);
+        GI::Repository repo;
+        repo.prepend_search_path(priv_typelib_dir);
     }
     auto& registry = Gjs::NativeModuleDefineFuncs::get();
     registry.add("_promiseNative", gjs_define_native_promise_stuff);
@@ -1004,9 +1005,11 @@ void GjsContextPrivate::stop_draining_job_queue(void) {
     m_dispatcher.stop();
 }
 
-JSObject* GjsContextPrivate::getIncumbentGlobal(JSContext* cx) {
+bool GjsContextPrivate::getHostDefinedData(JSContext* cx,
+                                           JS::MutableHandleObject data) const {
     // This is equivalent to SpiderMonkey's behavior.
-    return JS::CurrentGlobalOrNull(cx);
+    data.set(JS::CurrentGlobalOrNull(cx));
+    return true;
 }
 
 // See engine.cpp and JS::SetJobQueue().
@@ -1731,7 +1734,7 @@ bool GjsContextPrivate::eval_with_scope(JS::HandleObject scope_object,
     if (!buf.init(m_cx, source, source_len, JS::SourceOwnership::Borrowed))
         return false;
 
-    JS::RootedObjectVector scope_chain(m_cx);
+    JS::EnvironmentChain scope_chain{m_cx, JS::SupportUnscopables::No};
     if (!scope_chain.append(eval_obj)) {
         JS_ReportOutOfMemory(m_cx);
         return false;
