@@ -23,15 +23,22 @@
 #include <js/Value.h>
 #include <js/experimental/CodeCoverage.h>  // for EnableCodeCoverage
 #include <jsapi.h>                         // for JS_WrapObject
+#include <mozilla/Result.h>
+#include <mozilla/Try.h>
 
 #include "gjs/atoms.h"
+#include "gjs/auto.h"
 #include "gjs/context-private.h"
 #include "gjs/context.h"
 #include "gjs/coverage.h"
+#include "gjs/gerror-result.h"
 #include "gjs/global.h"
 #include "gjs/jsapi-util.h"
 #include "gjs/macros.h"
 
+using Gjs::GErrorResult;
+using mozilla::Err, mozilla::Ok;
+
 static bool s_coverage_enabled = false;
 
 struct _GjsCoverage {
@@ -68,26 +75,35 @@ static GParamSpec *properties[PROP_N] = { NULL, };
     return path;
 }
 
-[[nodiscard]] static bool write_source_file_header(GOutputStream* stream,
-                                                   GFile* source_file,
-                                                   GError** error) {
-    GjsAutoChar path = get_file_identifier(source_file);
-    return g_output_stream_printf(stream, NULL, NULL, error, "SF:%s\n", path.get());
+[[nodiscard]]
+static GErrorResult<> write_source_file_header(GOutputStream* stream,
+                                               GFile* source_file) {
+    Gjs::AutoChar path{get_file_identifier(source_file)};
+    Gjs::AutoError error;
+    if (!g_output_stream_printf(stream, nullptr, nullptr, error.out(),
+                                "SF:%s\n", path.get()))
+        return Err(error.release());
+    return Ok{};
 }
 
-[[nodiscard]] static bool copy_source_file_to_coverage_output(
-    GFile* source_file, GFile* destination_file, GError** error) {
+[[nodiscard]]
+static GErrorResult<> copy_source_file_to_coverage_output(
+    GFile* source_file, GFile* destination_file) {
     /* We need to recursively make the directory we
      * want to copy to, as g_file_copy doesn't do that */
-    GjsAutoUnref<GFile> destination_dir = g_file_get_parent(destination_file);
-    if (!g_file_make_directory_with_parents(destination_dir, NULL, error)) {
-        if (!g_error_matches(*error, G_IO_ERROR, G_IO_ERROR_EXISTS))
-            return false;
-        g_clear_error(error);
+    Gjs::AutoError error;
+    Gjs::AutoUnref<GFile> destination_dir{g_file_get_parent(destination_file)};
+    if (!g_file_make_directory_with_parents(destination_dir, nullptr,
+                                            error.out())) {
+        if (!g_error_matches(error, G_IO_ERROR, G_IO_ERROR_EXISTS))
+            return Err(error.release());
+        error.reset();
     }
 
-    return g_file_copy(source_file, destination_file, G_FILE_COPY_OVERWRITE,
-                       nullptr, nullptr, nullptr, error);
+    if (!g_file_copy(source_file, destination_file, G_FILE_COPY_OVERWRITE,
+                     nullptr, nullptr, nullptr, error.out()))
+        return Err(error.release());
+    return Ok{};
 }
 
 /* This function will strip a URI scheme and return
@@ -129,7 +145,7 @@ static GParamSpec *properties[PROP_N] = { NULL, };
  */
 [[nodiscard]] static char* find_diverging_child_components(GFile* child,
                                                            GFile* parent) {
-    GjsAutoUnref<GFile> ancestor(parent, GjsAutoTakeOwnership());
+    Gjs::AutoUnref<GFile> ancestor{parent, Gjs::TakeOwnership{}};
     while (ancestor) {
         char *relpath = g_file_get_relative_path(ancestor, child);
         if (relpath)
@@ -141,53 +157,57 @@ static GParamSpec *properties[PROP_N] = { NULL, };
     /* This is a special case of getting the URI below. The difference is that
      * this gives you a regular path name; getting it through the URI would
      * give a URI-encoded path (%20 for spaces, etc.) */
-    GjsAutoUnref<GFile> root = g_file_new_for_path("/");
+    Gjs::AutoUnref<GFile> root{g_file_new_for_path("/")};
     char* child_path = g_file_get_relative_path(root, child);
     if (child_path)
         return child_path;
 
-    GjsAutoChar child_uri = g_file_get_uri(child);
+    Gjs::AutoChar child_uri{g_file_get_uri(child)};
     return strip_uri_scheme(child_uri);
 }
 
 [[nodiscard]] static bool filename_has_coverage_prefixes(GjsCoverage* self,
                                                          const char* filename) {
     auto priv = static_cast<GjsCoveragePrivate *>(gjs_coverage_get_instance_private(self));
-    GjsAutoChar workdir = g_get_current_dir();
-    GjsAutoChar abs_filename = g_canonicalize_filename(filename, workdir);
+    Gjs::AutoChar workdir{g_get_current_dir()};
+    Gjs::AutoChar abs_filename{g_canonicalize_filename(filename, workdir)};
 
     for (const char * const *prefix = priv->prefixes; *prefix; prefix++) {
-        GjsAutoChar abs_prefix = g_canonicalize_filename(*prefix, workdir);
+        Gjs::AutoChar abs_prefix{g_canonicalize_filename(*prefix, workdir)};
         if (g_str_has_prefix(abs_filename, abs_prefix))
             return true;
     }
     return false;
 }
 
-static inline bool
-write_line(GOutputStream *out,
-           const char    *line,
-           GError       **error)
-{
-    return g_output_stream_printf(out, nullptr, nullptr, error, "%s\n", line);
+[[nodiscard]]
+static inline GErrorResult<> write_line(GOutputStream* out, const char* line) {
+    Gjs::AutoError error;
+    if (!g_output_stream_printf(out, nullptr, nullptr, error.out(), "%s\n",
+                                line))
+        return Err(error.release());
+    return Ok{};
 }
 
-[[nodiscard]] static GjsAutoUnref<GFile> write_statistics_internal(
-    GjsCoverage* coverage, JSContext* cx, GError** error) {
+[[nodiscard]]
+GErrorResult<Gjs::AutoUnref<GFile>> write_statistics_internal(
+    GjsCoverage* coverage, JSContext* cx) {
     if (!s_coverage_enabled) {
         g_critical(
             "Code coverage requested, but gjs_coverage_enable() was not called."
             " You must call this function before creating any GjsContext.");
-        return nullptr;
+        return Gjs::AutoUnref<GFile>{};
     }
 
     GjsCoveragePrivate *priv = (GjsCoveragePrivate *) gjs_coverage_get_instance_private(coverage);
 
     /* Create output directory if it doesn't exist */
-    if (!g_file_make_directory_with_parents(priv->output_dir, nullptr, error)) {
-        if (!g_error_matches(*error, G_IO_ERROR, G_IO_ERROR_EXISTS))
-            return nullptr;
-        g_clear_error(error);
+    Gjs::AutoError error;
+    if (!g_file_make_directory_with_parents(priv->output_dir, nullptr,
+                                            error.out())) {
+        if (!g_error_matches(error, G_IO_ERROR, G_IO_ERROR_EXISTS))
+            return Err(error.release());
+        error.reset();
     }
 
     GFile *output_file = g_file_get_child(priv->output_dir, "coverage.lcov");
@@ -195,15 +215,12 @@ write_line(GOutputStream *out,
     size_t lcov_length;
     JS::UniqueChars lcov = js::GetCodeCoverageSummary(cx, &lcov_length);
 
-    GjsAutoUnref<GOutputStream> ostream =
-        G_OUTPUT_STREAM(g_file_append_to(output_file,
-                                         G_FILE_CREATE_NONE,
-                                         NULL,
-                                         error));
+    Gjs::AutoUnref<GOutputStream> ostream{G_OUTPUT_STREAM(g_file_append_to(
+        output_file, G_FILE_CREATE_NONE, nullptr, error.out()))};
     if (!ostream)
-        return nullptr;
+        return Err(error.release());
 
-    GjsAutoStrv lcov_lines = g_strsplit(lcov.get(), "\n", -1);
+    Gjs::AutoStrv lcov_lines{g_strsplit(lcov.get(), "\n", -1)};
     const char* test_name = NULL;
     bool ignoring_file = false;
 
@@ -227,32 +244,30 @@ write_line(GOutputStream *out,
             }
 
             /* Now we can write the test name before writing the source file */
-            if (!write_line(ostream, test_name, error))
-                return nullptr;
+            MOZ_TRY(write_line(ostream, test_name));
 
             /* The source file could be a resource, so we must use
              * g_file_new_for_commandline_arg() to disambiguate between URIs and
              * filesystem paths. */
-            GjsAutoUnref<GFile> source_file = g_file_new_for_commandline_arg(filename);
-            GjsAutoChar diverged_paths =
-                find_diverging_child_components(source_file, priv->output_dir);
-            GjsAutoUnref<GFile> destination_file =
-                g_file_resolve_relative_path(priv->output_dir, diverged_paths);
-            if (!copy_source_file_to_coverage_output(source_file, destination_file, error))
-                return nullptr;
+            Gjs::AutoUnref<GFile> source_file{
+                g_file_new_for_commandline_arg(filename)};
+            Gjs::AutoChar diverged_paths{
+                find_diverging_child_components(source_file, priv->output_dir)};
+            Gjs::AutoUnref<GFile> destination_file{
+                g_file_resolve_relative_path(priv->output_dir, diverged_paths)};
+            MOZ_TRY(copy_source_file_to_coverage_output(source_file,
+                                                        destination_file));
 
             /* Rewrite the source file path to be relative to the output
              * dir so that genhtml will find it */
-            if (!write_source_file_header(ostream, destination_file, error))
-                return nullptr;
+            MOZ_TRY(write_source_file_header(ostream, destination_file));
             continue;
         }
 
-        if (!write_line(ostream, *iter, error))
-            return nullptr;
+        MOZ_TRY(write_line(ostream, *iter));
     }
 
-    return output_file;
+    return Gjs::AutoUnref<GFile>{output_file};
 }
 
 /**
@@ -273,18 +288,18 @@ void
 gjs_coverage_write_statistics(GjsCoverage *coverage)
 {
     auto priv = static_cast<GjsCoveragePrivate *>(gjs_coverage_get_instance_private(coverage));
-    GjsAutoError error;
-
     auto cx = static_cast<JSContext *>(gjs_context_get_native_context(priv->context));
     Gjs::AutoMainRealm ar{cx};
 
-    GjsAutoUnref<GFile> output_file = write_statistics_internal(coverage, cx, &error);
-    if (!output_file) {
-        g_critical("Error writing coverage data: %s", error->message);
+    GErrorResult<Gjs::AutoUnref<GFile>> result{
+        write_statistics_internal(coverage, cx)};
+    if (result.isErr()) {
+        g_critical("Error writing coverage data: %s",
+                   result.inspectErr()->message);
         return;
     }
 
-    GjsAutoChar output_file_path = g_file_get_path(output_file);
+    Gjs::AutoChar output_file_path{g_file_get_path(result.unwrap())};
     g_message("Wrote coverage statistics to %s", output_file_path.get());
 }
 
