@@ -8,9 +8,10 @@
 
 #include <config.h>
 
-#include <cstddef>  // for nullptr_t
+// https://github.com/include-what-you-use/include-what-you-use/issues/1791
+#include <cstddef>  // IWYU pragma: keep
 #include <memory>
-#include <new>
+#include <new>  // IWYU pragma: keep (actually for clangd)
 
 #include <glib.h>
 
@@ -23,6 +24,8 @@
 
 #include "util/log.h"
 
+namespace JS { template <typename T> struct GCPolicy; }
+
 /* jsapi-util-root.h - Utilities for dealing with the lifetime and ownership of
  * JS Objects and other things that can be collected by the garbage collector
  * (collectively called "GC things.")
@@ -221,4 +224,36 @@ class GjsMaybeOwned {
     [[nodiscard]] bool rooted() const { return m_root != nullptr; }
 };
 
+namespace Gjs {
+
+template <typename T>
+class WeakPtr : public JS::Heap<T> {
+ public:
+    using JS::Heap<T>::Heap;
+    using JS::Heap<T>::operator=;
+};
+
+}  // namespace Gjs
+
+namespace JS {
+
+template <typename T>
+struct GCPolicy<Gjs::WeakPtr<T>> {
+    static void trace(JSTracer* trc, Gjs::WeakPtr<T>* thingp,
+                      const char* name) {
+        return JS::TraceEdge(trc, thingp, name);
+    }
+
+    static bool traceWeak(JSTracer* trc, Gjs::WeakPtr<T>* thingp) {
+        return js::gc::TraceWeakEdge(trc, thingp);
+    }
+
+    static bool needsSweep(JSTracer* trc, const Gjs::WeakPtr<T>* thingp) {
+        Gjs::WeakPtr<T> thing{*thingp};
+        return !js::gc::TraceWeakEdge(trc, &thing);
+    }
+};
+
+}  // namespace JS
+
 #endif  // GJS_JSAPI_UTIL_ROOT_H_
