@@ -396,11 +396,6 @@ describe('Gio.FileEnumerator overrides', function () {
 });
 
 describe('Gio.DesktopAppInfo fallback', function () {
-    const requiredVersion =
-        GLib.MAJOR_VERSION > 2 ||
-            (GLib.MAJOR_VERSION === 2 &&
-                (GLib.MINOR_VERSION > 85 ||
-                    GLib.MINOR_VERSION === 85 && GLib.MICRO_VERSION >= 5));
     let keyFile;
     const desktopFileContent = `[Desktop Entry]
 Version=1.0
@@ -417,15 +412,9 @@ Exec=${GLib.find_program_in_path('sh')}
     beforeEach(function () {
         if (!GioUnix)
             pending('Not supported platform');
-
-        if (!requiredVersion)
-            pending('Installed Gio is not new enough for this test');
     });
 
     function expectDeprecationWarning(testFunction) {
-        if (!requiredVersion)
-            pending('Installed Gio is not new enough for this test');
-
         GLib.test_expect_message('Gjs', GLib.LogLevelFlags.LEVEL_WARNING,
             '*Gio.DesktopAppInfo has been moved to a separate platform-specific library. ' +
             'Please update your code to use GioUnix.DesktopAppInfo instead*');
@@ -441,27 +430,32 @@ Exec=${GLib.find_program_in_path('sh')}
     it('can be created using Gio wrapper', function () {
         expectDeprecationWarning(() =>
             expect(Gio.DesktopAppInfo.new_from_keyfile(keyFile)).not.toBeNull());
-        expect(Gio.DesktopAppInfo.new_from_keyfile(keyFile)).not.toBeNull();
+        expectDeprecationWarning(() =>
+            expect(Gio.DesktopAppInfo.new_from_keyfile(keyFile)).not.toBeNull());
     });
 
     describe('provides platform-independent functions', function () {
         [Gio, GioUnix].forEach(ns => it(`when created from ${ns.__name__}`, function () {
-            if (!requiredVersion)
-                pending('Installed Gio is not new enough for this test');
+            const maybeExpectDeprecationWarning = ns === Gio
+                ? expectDeprecationWarning : tf => tf();
 
-            const appInfo = ns.DesktopAppInfo.new_from_keyfile(keyFile);
-            expect(appInfo.get_name()).toBe('Some Application');
+            maybeExpectDeprecationWarning(() => {
+                const appInfo = ns.DesktopAppInfo.new_from_keyfile(keyFile);
+                expect(appInfo.get_name()).toBe('Some Application');
+            });
         }));
     });
 
     describe('provides unix-only functions', function () {
         [Gio, GioUnix].forEach(ns => it(`when created from ${ns.__name__}`, function () {
-            if (!requiredVersion)
-                pending('Installed Gio is not new enough for this test');
+            const maybeExpectDeprecationWarning = ns === Gio
+                ? expectDeprecationWarning : tf => tf();
 
-            const appInfo = ns.DesktopAppInfo.new_from_keyfile(keyFile);
-            expect(appInfo.has_key('Name')).toBeTrue();
-            expect(appInfo.get_string('Name')).toBe('Some Application');
+            maybeExpectDeprecationWarning(() => {
+                const appInfo = ns.DesktopAppInfo.new_from_keyfile(keyFile);
+                expect(appInfo.has_key('Name')).toBeTrue();
+                expect(appInfo.get_string('Name')).toBe('Some Application');
+            });
         }));
     });
 });
