@@ -9,7 +9,7 @@
 #include <memory>
 
 #include <cairo.h>
-#include <girepository.h>
+#include <girepository/girepository.h>
 #include <glib.h>
 
 #include <js/Array.h>  // for JS::NewArrayObject
