@@ -27,6 +27,10 @@
 #include <glib.h>
 #include <glib/gprintf.h>  // for g_fprintf
 
+#ifdef HAVE_READLINE_READLINE_H
+#    include <gio/gunixinputstream.h>
+#endif
+
 #include <js/CallAndConstruct.h>
 #include <js/CallArgs.h>
 #include <js/CharacterEncoding.h>  // for JS_EncodeStringToUTF8
@@ -44,18 +48,23 @@
 #include <js/ValueArray.h>
 #include <js/Warnings.h>
 #include <jsapi.h>  // for JS_NewPlainObject
+#include <mozilla/Maybe.h>
 
 #include "gjs/atoms.h"
+#include "gjs/auto.h"
 #include "gjs/context-private.h"
 #include "gjs/global.h"
 #include "gjs/jsapi-util.h"
 #include "gjs/macros.h"
 #include "modules/console.h"
+#include "util/console.h"
 
 namespace mozilla {
 union Utf8Unit;
 }
 
+using mozilla::Maybe, mozilla::Nothing, mozilla::Some;
+
 static void gjs_console_warning_reporter(JSContext*, JSErrorReport* report) {
     JS::PrintError(stderr, report, /* reportWarnings = */ true);
 }
@@ -92,7 +101,7 @@ public:
             if (!stack_str) {
                 g_printerr("(Unable to print stack trace)\n");
             } else {
-                GjsAutoChar encoded_stack_str{g_filename_from_utf8(
+                Gjs::AutoChar encoded_stack_str{g_filename_from_utf8(
                     stack_str.get(), -1, nullptr, nullptr, nullptr)};
                 if (!encoded_stack_str)
                     g_printerr("(Unable to print stack trace)\n");
@@ -140,23 +149,72 @@ class AutoCatchCtrlC {
 sigjmp_buf AutoCatchCtrlC::jump_buffer;
 #endif  // HAVE_SIGNAL_H
 
-[[nodiscard]] static bool gjs_console_readline(char** bufp,
-                                               const char* prompt) {
 #ifdef HAVE_READLINE_READLINE_H
-    char *line;
-    line = readline(prompt);
-    if (!line)
+// Readline only has a global handler anyway, so may as well use global data
+static Maybe<std::string> rl_async_line{};
+static bool rl_async_done = true;
+
+static gboolean on_stdin_ready(GPollableInputStream* pollable, void*) {
+    while (g_pollable_input_stream_is_readable(pollable))
+        rl_callback_read_char();
+    return TRUE;  // don't remove source
+}
+
+static void on_readline_complete(char* line) {
+    rl_async_line = line ? Some(line) : Nothing();
+    rl_async_done = true;
+    // This needs to be called from the callback handler, otherwise an extra
+    // prompt is displayed.
+    rl_callback_handler_remove();
+}
+#endif
+
+[[nodiscard]]
+static bool gjs_console_readline(std::string* bufp, const char* prompt,
+                                 const char* repl_history_path
+                                 [[maybe_unused]]) {
+#ifdef HAVE_READLINE_READLINE_H
+    g_assert(rl_async_done && "should not attempt two parallel readline calls");
+
+    rl_callback_handler_install(prompt, on_readline_complete);
+    rl_async_done = false;
+
+    Gjs::AutoUnref<GInputStream> stdin_stream{
+        g_unix_input_stream_new(fileno(rl_instream), /* close = */ false)};
+    Gjs::AutoUnref<GSource> stdin_source{g_pollable_input_stream_create_source(
+        G_POLLABLE_INPUT_STREAM(stdin_stream.get()), nullptr)};
+    g_source_set_callback(stdin_source, G_SOURCE_FUNC(on_stdin_ready), nullptr,
+                          nullptr);
+
+    Gjs::AutoPointer<GMainContext, GMainContext, g_main_context_unref>
+        main_context{g_main_context_ref_thread_default()};
+    unsigned tag = g_source_attach(stdin_source, main_context);
+    stdin_source.release();
+
+    while (!rl_async_done) {
+        // Yield to other things while waiting for input
+        while (g_main_context_pending(main_context))
+            g_main_context_iteration(main_context, /* may_block = */ false);
+    }
+
+    g_source_remove(tag);
+
+    if (!rl_async_line)
         return false;
-    if (line[0] != '\0')
-        add_history(line);
-    *bufp = line;
+
+    *bufp = rl_async_line.extract();
+
+    if ((*bufp)[0] != '\0') {
+        add_history(bufp->c_str());
+        gjs_console_write_repl_history(repl_history_path);
+    }
 #else   // !HAVE_READLINE_READLINE_H
     char line[256];
     fprintf(stdout, "%s", prompt);
     fflush(stdout);
     if (!fgets(line, sizeof line, stdin))
         return false;
-    *bufp = g_strdup(line);
+    *bufp = line;
 #endif  // !HAVE_READLINE_READLINE_H
     return true;
 }
@@ -229,9 +287,9 @@ gjs_console_interact(JSContext *context,
     JS::CallArgs argv = JS::CallArgsFromVp(argc, vp);
     volatile bool eof, exit_warning;  // accessed after setjmp()
     JS::RootedObject global{context, JS::CurrentGlobalOrNull(context)};
-    char* temp_buf;
     volatile int lineno;     // accessed after setjmp()
     volatile int startline;  // accessed after setjmp()
+    GjsContextPrivate* gjs = GjsContextPrivate::from_cx(context);
 
 #ifndef HAVE_READLINE_READLINE_H
     int rl_end = 0;  // nonzero if using readline and any text is typed in
@@ -244,7 +302,6 @@ gjs_console_interact(JSContext *context,
     // Separate initialization from declaration because of possible overwriting
     // when siglongjmp() jumps into this function
     eof = exit_warning = false;
-    temp_buf = nullptr;
     lineno = 1;
     do {
         /*
@@ -279,14 +336,15 @@ gjs_console_interact(JSContext *context,
             }
 #endif  // HAVE_SIGNAL_H
 
-            if (!gjs_console_readline(
-                    &temp_buf, startline == lineno ? "gjs> " : ".... ")) {
+            std::string temp_buf;
+            if (!gjs_console_readline(&temp_buf,
+                                      startline == lineno ? "gjs> " : ".... ",
+                                      gjs->repl_history_path())) {
                 eof = true;
                 break;
             }
             buffer += temp_buf;
             buffer += "\n";
-            g_free(temp_buf);
             lineno++;
         } while (!JS_Utf8BufferIsCompilableUnit(context, global, buffer.c_str(),
                                                 buffer.size()));
@@ -298,7 +356,6 @@ gjs_console_interact(JSContext *context,
         }
         exit_warning = false;
 
-        GjsContextPrivate* gjs = GjsContextPrivate::from_cx(context);
         ok = gjs->run_jobs_fallible() && ok;
 
         if (!ok) {
