@@ -5,8 +5,11 @@ const system = import.meta.importSync('system');
 
 export let {
     addressOf,
+    addressOfGObject,
     breakpoint,
     clearDateCaches,
+    dumpHeap,
+    dumpMemoryInfo,
     exit,
     gc,
     programArgs,
@@ -18,8 +21,11 @@ export let {
 
 export default {
     addressOf,
+    addressOfGObject,
     breakpoint,
     clearDateCaches,
+    dumpHeap,
+    dumpMemoryInfo,
     exit,
     gc,
     programArgs,
