@@ -1,5 +1,5 @@
 /* -*- indent-tabs-mode: nil; js-indent-level: 4 -*- */
-/* global debuggee, quit, loadNative, readline, uneval */
+/* global debuggee, quit, loadNative, readline, uneval, getSourceMapRegistry */
 // SPDX-License-Identifier: MPL-2.0
 // SPDX-FileCopyrightText: 2011 Mozilla Foundation and contributors
 
@@ -23,6 +23,7 @@ var nextDebuggeeValueIndex = 1;
 var lastExc = null;
 var options = {pretty: true, colors: true, ignoreCaughtExceptions: true};
 var breakpoints = [undefined];  // Breakpoint numbers start at 1
+var skipUnwindHandler = false;
 
 // Cleanup functions to run when we next re-enter the repl.
 var replCleanups = [];
@@ -31,9 +32,35 @@ var replCleanups = [];
 function dvToString(v) {
     if (typeof v === 'undefined')
         return 'undefined';  // uneval(undefined) === '(void 0)', confusing
-    if (v === null)
-        return 'null';  // typeof null === 'object', so avoid that case
-    return typeof v !== 'object' || v === null ? uneval(v) : `[object ${v.class}]`;
+    if (typeof v === 'object' && v !== null)
+        return `[object ${v.class}]`;
+    const s = uneval(v);
+    if (s.length > 400)
+        return `${s.substr(0, 400)}...<${s.length - 400} more bytes>...`;
+    return s;
+}
+
+// Build a nested tree of all private fields wherever they reside. Each level has KV tuples and their descendents:
+// {cur: [[key1, value1], ...], children: {key1: {...next level}}}
+function getProperties(dv, result, seen = new WeakSet()) {
+    if (!dv || seen.has(dv))
+        return;
+
+    if (typeof dv === 'object')
+        seen.add(dv);
+
+    const privateKVs = dv.getOwnPrivateProperties?.().map(k => [k.description, dv.getProperty(k).return]) ?? [];
+    const nonPrivateKVs = dv.getOwnPropertyNames?.().concat(dv.getOwnPropertySymbols()).map(k => [k, dv.getProperty(k).return]) ?? [];
+    result.cur = privateKVs;
+
+    result.children = {};
+    // a private field can be under a non-private field
+    privateKVs.concat(nonPrivateKVs).forEach(([k, v]) => {
+        result.children[k] = {};
+        getProperties(v, result.children[k], seen);
+    });
+    // prettyPrint in the debuggee compartment needs access to the original private field value and not Debugger.Object
+    result.cur.forEach(kv => kv[1]?.unsafeDereference && (kv[1] = kv[1].unsafeDereference()));
 }
 
 function debuggeeValueToString(dv, style = {pretty: options.pretty}) {
@@ -50,28 +77,27 @@ function debuggeeValueToString(dv, style = {pretty: options.pretty}) {
     }
 
     const dvrepr = dvToString(dv);
-    if (!style.pretty || dv === null || typeof dv !== 'object')
+    if (!style.pretty || (typeof dv !== 'object') || (dv === null))
         return [dvrepr, undefined];
 
+    const exec = debuggeeGlobalWrapper.executeInGlobalWithBindings.bind(debuggeeGlobalWrapper);
+
     if (['TypeError', 'Error', 'GIRespositoryNamespace', 'GObject_Object'].includes(dv.class)) {
-        const errval = debuggeeGlobalWrapper.executeInGlobalWithBindings(
-            'v.toString()', {v: dv});
+        const errval = exec('v.toString()', {v: dv});
         return [dvrepr, errval['return']];
     }
 
     if (style.brief)
         return [dvrepr, dvrepr];
 
-    const str = debuggeeGlobalWrapper.executeInGlobalWithBindings(
-        'imports._print.getPrettyPrintFunction(globalThis)(v)', {v: dv});
-
+    const properties = {};
+    getProperties(dv, properties);
+    const str = exec('imports._print.getPrettyPrintFunction(globalThis)(v, extra)', {v: dv, extra: dv.makeDebuggeeValue(properties)});
     if ('throw' in str) {
         if (style.noerror)
             return [dvrepr, undefined];
 
-        const substyle = {};
-        Object.assign(substyle, style);
-        substyle.noerror = true;
+        const substyle = {...style, noerror: true};
         return [dvrepr, debuggeeValueToString(str.throw, substyle)];
     }
 
@@ -136,10 +162,34 @@ Object.defineProperty(Debugger.Frame.prototype, 'line', {
     },
 });
 
+Object.defineProperty(Debugger.Frame.prototype, 'column', {
+    configurable: true,
+    enumerable: false,
+    get() {
+        return this.script?.getOffsetLocation(this.offset).columnNumber ?? null;
+    },
+});
+
 Debugger.Script.prototype.describeOffset = function describeOffset(offset) {
     const {lineNumber, columnNumber} = this.getOffsetLocation(offset);
     const url = this.url || '<unknown>';
-    return `${url}:${lineNumber}:${columnNumber}`;
+    const registry = getSourceMapRegistry();
+    const consumer = registry.get(url);
+
+    let description = `${url}:${lineNumber}:${columnNumber}`;
+    const original = consumer?.originalPositionFor({line: lineNumber, column: columnNumber});
+
+    if (original?.source || Number.isInteger(original?.line) || Number.isInteger(original?.column))
+        description += ' -> ';
+
+    if (original?.source)
+        description += original.source;
+    if (Number.isInteger(original?.line))
+        description += `:${original.line}`;
+    if (Number.isInteger(original?.column))
+        description += `:${original.column + 1}`;
+
+    return description;
 };
 
 function showFrame(f, n, option = {btCommand: false, fullOption: false}) {
@@ -185,6 +235,36 @@ function saveExcursion(fn) {
     }
 }
 
+// Evaluate @expr in the current frame, logging and suppressing any exceptions
+function evalInFrame(expr) {
+    if (!focusedFrame) {
+        print('No stack');
+        return;
+    }
+
+    skipUnwindHandler = true;
+    let cv;
+    try {
+        cv = saveExcursion(
+            () => focusedFrame.evalWithBindings(`(${expr})`, debuggeeValues));
+    } finally {
+        skipUnwindHandler = false;
+    }
+
+    if (cv === null) {
+        print(`Debuggee died while evaluating ${expr}`);
+        return;
+    }
+
+    const {throw: exc, return: dv} = cv;
+    if (exc) {
+        print(`Exception caught while evaluating ${expr}: ${dvToString(exc)}`);
+        return;
+    }
+
+    return {value: dv};
+}
+
 // Accept debugger commands starting with '#' so that scripting the debugger
 // can be annotated
 function commentCommand(comment) {
@@ -231,9 +311,9 @@ function listCommand(option) {
         print('No frame to list from');
         return;
     }
-    let lineNumber = focusedFrame.line;
+    let lineNumber = focusedFrame.line, columnNumber = focusedFrame.column;
     if (option === '') {
-        printSurroundingLines(lineNumber);
+        printSurroundingLines(lineNumber, columnNumber);
         return;
     }
     let currentLine = Number(option);
@@ -244,11 +324,23 @@ function listCommand(option) {
         print('Unknown option');
 }
 
-function printSurroundingLines(currentLine = 1) {
-    let sourceLines = focusedFrame.script.source.text.split('\n');
-    let lastLine = sourceLines.length - 1;
+function printSurroundingLines(currentLine = 1, columnNumber = 1) {
+    const registry = getSourceMapRegistry();
+    const sourceUrl = focusedFrame.script.source.url;
+    const consumer = registry.get(sourceUrl);
+    const originalObj = consumer?.originalPositionFor({line: currentLine, column: columnNumber - 1});
+    const sourceMapContents = originalObj?.source ? consumer?.sourceContentFor(originalObj.source, true) : null;
+    let sourceLines;
+    if (sourceMapContents) {
+        sourceLines = sourceMapContents.split('\n');
+        currentLine = originalObj?.line ?? 1;
+    } else {
+        sourceLines = focusedFrame.script.source.text.split('\n');
+    }
+    const lastLine = sourceLines.length;
     let maxLineLimit = Math.min(lastLine, currentLine + 5);
     let minLineLimit = Math.max(1, currentLine - 5);
+
     for (let i = minLineLimit; i < maxLineLimit + 1; i++) {
         if (i === currentLine) {
             const code = colorCode('1');
@@ -348,9 +440,34 @@ expr may also reference the variables $1, $2, ... for already printed
 expressions, or $$ for the most recently printed expression.`;
 
 function keysCommand(rest) {
-    return doPrint(`Object.keys(${rest})`);
+    if (!rest) {
+        print("Missing argument. See 'help keys'");
+        return;
+    }
+
+    const result = evalInFrame(rest);
+    if (!result)
+        return;
+
+    const dv = result.value;
+    if (!(dv instanceof Debugger.Object)) {
+        print(`${rest} is ${dvToString(dv)}, not an object`);
+        return;
+    }
+    const names = dv.getOwnPropertyNames();
+    const symbols = dv.getOwnPropertySymbols();
+    const privateFields = dv.getOwnPrivateProperties();
+    const keys = [
+        ...names.map(s => `"${s}"`),
+        ...symbols.map(s => `Symbol("${s.description}")`),
+        ...privateFields.map(s => `${s.description}`),
+    ];
+    if (keys.length === 0)
+        print('No own properties');
+    else
+        print(keys.join(', '));
 }
-keysCommand.summary = 'Prints keys of the given object';
+keysCommand.summary = 'Prints own properties of the given object';
 keysCommand.helpText = `USAGE
     keys <obj>
 
@@ -378,25 +495,15 @@ continueCommand.helpText = `USAGE
 
 function throwOrReturn(rest, action, defaultCompletion) {
     if (focusedFrame !== topFrame) {
-        print("To throw, you must select the newest frame (use 'frame 0').");
-        return;
-    }
-    if (focusedFrame === null) {
-        print('No stack.');
+        print(`To ${action}, you must select the newest frame (use 'frame 0')`);
         return;
     }
     if (rest === '')
         return [defaultCompletion];
 
-    const cv = saveExcursion(() => focusedFrame.eval(rest));
-    if (cv === null) {
-        print(`Debuggee died while determining what to ${action}. Stopped.`);
-        return;
-    }
-    if ('return' in cv)
-        return [{[action]: cv['return']}];
-    print(`Exception determining what to ${action}. Stopped.`);
-    showDebuggeeValue(cv.throw);
+    const result = evalInFrame(rest);
+    if (result)
+        return [{[action]: result.value}];
 }
 
 function throwCommand(rest) {
@@ -836,7 +943,7 @@ function runcmd(cmd) {
         return undefined;
 
     var first = pieces[0], rest = pieces[1];
-    if (!commands.hasOwnProperty(first)) {
+    if (!Object.hasOwn(commands, first)) {
         print(`unrecognized command '${first}'`);
         return undefined;
     }
@@ -896,6 +1003,9 @@ function onInitialEnterFrame(frame) {
 
 var dbg = new Debugger();
 dbg.onNewPromise = function ({promiseID, promiseAllocationSite}) {
+    // if the promise was not allocated by the script, allocation site is null
+    if (!promiseAllocationSite)
+        return undefined;
     const site = promiseAllocationSite.toString().split('\n')[0];
     print(`Promise ${promiseID} started from ${site}`);
     return undefined;
@@ -925,6 +1035,9 @@ dbg.onDebuggerStatement = function (frame) {
     });
 };
 dbg.onExceptionUnwind = function (frame, value) {
+    if (skipUnwindHandler)
+        return undefined;
+
     const willBeCaught = currentFrame => {
         while (currentFrame) {
             if (currentFrame.script.isInCatchScope(currentFrame.offset))
